@@ -1,5 +1,7 @@
 """
-Main interface for managedblockchain service type definitions.
+Type annotations for managedblockchain service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -13,10 +15,19 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from .literals import (
+    EditionType,
+    FrameworkType,
+    InvitationStatusType,
+    MemberStatusType,
+    NetworkStatusType,
+    NodeStatusType,
+    ProposalStatusType,
+    StateDBTypeType,
+    ThresholdComparatorType,
+    VoteValueType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -25,10 +36,26 @@ else:
 
 __all__ = (
     "ApprovalThresholdPolicyTypeDef",
+    "CreateMemberOutputTypeDef",
+    "CreateNetworkOutputTypeDef",
+    "CreateNodeOutputTypeDef",
+    "CreateProposalOutputTypeDef",
+    "GetMemberOutputTypeDef",
+    "GetNetworkOutputTypeDef",
+    "GetNodeOutputTypeDef",
+    "GetProposalOutputTypeDef",
     "InvitationTypeDef",
     "InviteActionTypeDef",
+    "ListInvitationsOutputTypeDef",
+    "ListMembersOutputTypeDef",
+    "ListNetworksOutputTypeDef",
+    "ListNodesOutputTypeDef",
+    "ListProposalVotesOutputTypeDef",
+    "ListProposalsOutputTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "LogConfigurationTypeDef",
     "LogConfigurationsTypeDef",
+    "MemberConfigurationTypeDef",
     "MemberFabricAttributesTypeDef",
     "MemberFabricConfigurationTypeDef",
     "MemberFabricLogPublishingConfigurationTypeDef",
@@ -41,8 +68,10 @@ __all__ = (
     "NetworkFabricAttributesTypeDef",
     "NetworkFabricConfigurationTypeDef",
     "NetworkFrameworkAttributesTypeDef",
+    "NetworkFrameworkConfigurationTypeDef",
     "NetworkSummaryTypeDef",
     "NetworkTypeDef",
+    "NodeConfigurationTypeDef",
     "NodeEthereumAttributesTypeDef",
     "NodeFabricAttributesTypeDef",
     "NodeFabricLogPublishingConfigurationTypeDef",
@@ -54,27 +83,9 @@ __all__ = (
     "ProposalSummaryTypeDef",
     "ProposalTypeDef",
     "RemoveActionTypeDef",
-    "ResponseMetadata",
+    "ResponseMetadataTypeDef",
     "VoteSummaryTypeDef",
     "VotingPolicyTypeDef",
-    "CreateMemberOutputTypeDef",
-    "CreateNetworkOutputTypeDef",
-    "CreateNodeOutputTypeDef",
-    "CreateProposalOutputTypeDef",
-    "GetMemberOutputTypeDef",
-    "GetNetworkOutputTypeDef",
-    "GetNodeOutputTypeDef",
-    "GetProposalOutputTypeDef",
-    "ListInvitationsOutputTypeDef",
-    "ListMembersOutputTypeDef",
-    "ListNetworksOutputTypeDef",
-    "ListNodesOutputTypeDef",
-    "ListProposalVotesOutputTypeDef",
-    "ListProposalsOutputTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "MemberConfigurationTypeDef",
-    "NetworkFrameworkConfigurationTypeDef",
-    "NodeConfigurationTypeDef",
 )
 
 ApprovalThresholdPolicyTypeDef = TypedDict(
@@ -82,338 +93,94 @@ ApprovalThresholdPolicyTypeDef = TypedDict(
     {
         "ThresholdPercentage": int,
         "ProposalDurationInHours": int,
-        "ThresholdComparator": Literal["GREATER_THAN", "GREATER_THAN_OR_EQUAL_TO"],
+        "ThresholdComparator": ThresholdComparatorType,
     },
     total=False,
 )
 
+CreateMemberOutputTypeDef = TypedDict(
+    "CreateMemberOutputTypeDef",
+    {
+        "MemberId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateNetworkOutputTypeDef = TypedDict(
+    "CreateNetworkOutputTypeDef",
+    {
+        "NetworkId": str,
+        "MemberId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateNodeOutputTypeDef = TypedDict(
+    "CreateNodeOutputTypeDef",
+    {
+        "NodeId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateProposalOutputTypeDef = TypedDict(
+    "CreateProposalOutputTypeDef",
+    {
+        "ProposalId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetMemberOutputTypeDef = TypedDict(
+    "GetMemberOutputTypeDef",
+    {
+        "Member": "MemberTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetNetworkOutputTypeDef = TypedDict(
+    "GetNetworkOutputTypeDef",
+    {
+        "Network": "NetworkTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetNodeOutputTypeDef = TypedDict(
+    "GetNodeOutputTypeDef",
+    {
+        "Node": "NodeTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetProposalOutputTypeDef = TypedDict(
+    "GetProposalOutputTypeDef",
+    {
+        "Proposal": "ProposalTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 InvitationTypeDef = TypedDict(
     "InvitationTypeDef",
     {
         "InvitationId": str,
         "CreationDate": datetime,
         "ExpirationDate": datetime,
-        "Status": Literal["PENDING", "ACCEPTED", "ACCEPTING", "REJECTED", "EXPIRED"],
+        "Status": InvitationStatusType,
         "NetworkSummary": "NetworkSummaryTypeDef",
         "Arn": str,
     },
     total=False,
 )
 
-InviteActionTypeDef = TypedDict("InviteActionTypeDef", {"Principal": str})
-
-LogConfigurationTypeDef = TypedDict("LogConfigurationTypeDef", {"Enabled": bool}, total=False)
-
-LogConfigurationsTypeDef = TypedDict(
-    "LogConfigurationsTypeDef", {"Cloudwatch": "LogConfigurationTypeDef"}, total=False
-)
-
-MemberFabricAttributesTypeDef = TypedDict(
-    "MemberFabricAttributesTypeDef", {"AdminUsername": str, "CaEndpoint": str}, total=False
-)
-
-MemberFabricConfigurationTypeDef = TypedDict(
-    "MemberFabricConfigurationTypeDef", {"AdminUsername": str, "AdminPassword": str}
-)
-
-MemberFabricLogPublishingConfigurationTypeDef = TypedDict(
-    "MemberFabricLogPublishingConfigurationTypeDef",
-    {"CaLogs": "LogConfigurationsTypeDef"},
-    total=False,
-)
-
-MemberFrameworkAttributesTypeDef = TypedDict(
-    "MemberFrameworkAttributesTypeDef", {"Fabric": "MemberFabricAttributesTypeDef"}, total=False
-)
-
-MemberFrameworkConfigurationTypeDef = TypedDict(
-    "MemberFrameworkConfigurationTypeDef",
-    {"Fabric": "MemberFabricConfigurationTypeDef"},
-    total=False,
-)
-
-MemberLogPublishingConfigurationTypeDef = TypedDict(
-    "MemberLogPublishingConfigurationTypeDef",
-    {"Fabric": "MemberFabricLogPublishingConfigurationTypeDef"},
-    total=False,
-)
-
-MemberSummaryTypeDef = TypedDict(
-    "MemberSummaryTypeDef",
+InviteActionTypeDef = TypedDict(
+    "InviteActionTypeDef",
     {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "Status": Literal[
-            "CREATING", "AVAILABLE", "CREATE_FAILED", "UPDATING", "DELETING", "DELETED"
-        ],
-        "CreationDate": datetime,
-        "IsOwned": bool,
-        "Arn": str,
+        "Principal": str,
     },
-    total=False,
-)
-
-MemberTypeDef = TypedDict(
-    "MemberTypeDef",
-    {
-        "NetworkId": str,
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "FrameworkAttributes": "MemberFrameworkAttributesTypeDef",
-        "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
-        "Status": Literal[
-            "CREATING", "AVAILABLE", "CREATE_FAILED", "UPDATING", "DELETING", "DELETED"
-        ],
-        "CreationDate": datetime,
-        "Tags": Dict[str, str],
-        "Arn": str,
-    },
-    total=False,
-)
-
-NetworkEthereumAttributesTypeDef = TypedDict(
-    "NetworkEthereumAttributesTypeDef", {"ChainId": str}, total=False
-)
-
-NetworkFabricAttributesTypeDef = TypedDict(
-    "NetworkFabricAttributesTypeDef",
-    {"OrderingServiceEndpoint": str, "Edition": Literal["STARTER", "STANDARD"]},
-    total=False,
-)
-
-NetworkFabricConfigurationTypeDef = TypedDict(
-    "NetworkFabricConfigurationTypeDef", {"Edition": Literal["STARTER", "STANDARD"]}
-)
-
-NetworkFrameworkAttributesTypeDef = TypedDict(
-    "NetworkFrameworkAttributesTypeDef",
-    {"Fabric": "NetworkFabricAttributesTypeDef", "Ethereum": "NetworkEthereumAttributesTypeDef"},
-    total=False,
-)
-
-NetworkSummaryTypeDef = TypedDict(
-    "NetworkSummaryTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "Framework": Literal["HYPERLEDGER_FABRIC", "ETHEREUM"],
-        "FrameworkVersion": str,
-        "Status": Literal["CREATING", "AVAILABLE", "CREATE_FAILED", "DELETING", "DELETED"],
-        "CreationDate": datetime,
-        "Arn": str,
-    },
-    total=False,
-)
-
-NetworkTypeDef = TypedDict(
-    "NetworkTypeDef",
-    {
-        "Id": str,
-        "Name": str,
-        "Description": str,
-        "Framework": Literal["HYPERLEDGER_FABRIC", "ETHEREUM"],
-        "FrameworkVersion": str,
-        "FrameworkAttributes": "NetworkFrameworkAttributesTypeDef",
-        "VpcEndpointServiceName": str,
-        "VotingPolicy": "VotingPolicyTypeDef",
-        "Status": Literal["CREATING", "AVAILABLE", "CREATE_FAILED", "DELETING", "DELETED"],
-        "CreationDate": datetime,
-        "Tags": Dict[str, str],
-        "Arn": str,
-    },
-    total=False,
-)
-
-NodeEthereumAttributesTypeDef = TypedDict(
-    "NodeEthereumAttributesTypeDef", {"HttpEndpoint": str, "WebSocketEndpoint": str}, total=False
-)
-
-NodeFabricAttributesTypeDef = TypedDict(
-    "NodeFabricAttributesTypeDef", {"PeerEndpoint": str, "PeerEventEndpoint": str}, total=False
-)
-
-NodeFabricLogPublishingConfigurationTypeDef = TypedDict(
-    "NodeFabricLogPublishingConfigurationTypeDef",
-    {"ChaincodeLogs": "LogConfigurationsTypeDef", "PeerLogs": "LogConfigurationsTypeDef"},
-    total=False,
-)
-
-NodeFrameworkAttributesTypeDef = TypedDict(
-    "NodeFrameworkAttributesTypeDef",
-    {"Fabric": "NodeFabricAttributesTypeDef", "Ethereum": "NodeEthereumAttributesTypeDef"},
-    total=False,
-)
-
-NodeLogPublishingConfigurationTypeDef = TypedDict(
-    "NodeLogPublishingConfigurationTypeDef",
-    {"Fabric": "NodeFabricLogPublishingConfigurationTypeDef"},
-    total=False,
-)
-
-NodeSummaryTypeDef = TypedDict(
-    "NodeSummaryTypeDef",
-    {
-        "Id": str,
-        "Status": Literal[
-            "CREATING",
-            "AVAILABLE",
-            "UNHEALTHY",
-            "CREATE_FAILED",
-            "UPDATING",
-            "DELETING",
-            "DELETED",
-            "FAILED",
-        ],
-        "CreationDate": datetime,
-        "AvailabilityZone": str,
-        "InstanceType": str,
-        "Arn": str,
-    },
-    total=False,
-)
-
-NodeTypeDef = TypedDict(
-    "NodeTypeDef",
-    {
-        "NetworkId": str,
-        "MemberId": str,
-        "Id": str,
-        "InstanceType": str,
-        "AvailabilityZone": str,
-        "FrameworkAttributes": "NodeFrameworkAttributesTypeDef",
-        "LogPublishingConfiguration": "NodeLogPublishingConfigurationTypeDef",
-        "StateDB": Literal["LevelDB", "CouchDB"],
-        "Status": Literal[
-            "CREATING",
-            "AVAILABLE",
-            "UNHEALTHY",
-            "CREATE_FAILED",
-            "UPDATING",
-            "DELETING",
-            "DELETED",
-            "FAILED",
-        ],
-        "CreationDate": datetime,
-        "Tags": Dict[str, str],
-        "Arn": str,
-    },
-    total=False,
-)
-
-ProposalActionsTypeDef = TypedDict(
-    "ProposalActionsTypeDef",
-    {"Invitations": List["InviteActionTypeDef"], "Removals": List["RemoveActionTypeDef"]},
-    total=False,
-)
-
-ProposalSummaryTypeDef = TypedDict(
-    "ProposalSummaryTypeDef",
-    {
-        "ProposalId": str,
-        "Description": str,
-        "ProposedByMemberId": str,
-        "ProposedByMemberName": str,
-        "Status": Literal["IN_PROGRESS", "APPROVED", "REJECTED", "EXPIRED", "ACTION_FAILED"],
-        "CreationDate": datetime,
-        "ExpirationDate": datetime,
-        "Arn": str,
-    },
-    total=False,
-)
-
-ProposalTypeDef = TypedDict(
-    "ProposalTypeDef",
-    {
-        "ProposalId": str,
-        "NetworkId": str,
-        "Description": str,
-        "Actions": "ProposalActionsTypeDef",
-        "ProposedByMemberId": str,
-        "ProposedByMemberName": str,
-        "Status": Literal["IN_PROGRESS", "APPROVED", "REJECTED", "EXPIRED", "ACTION_FAILED"],
-        "CreationDate": datetime,
-        "ExpirationDate": datetime,
-        "YesVoteCount": int,
-        "NoVoteCount": int,
-        "OutstandingVoteCount": int,
-        "Tags": Dict[str, str],
-        "Arn": str,
-    },
-    total=False,
-)
-
-RemoveActionTypeDef = TypedDict("RemoveActionTypeDef", {"MemberId": str})
-
-ResponseMetadata = TypedDict(
-    "ResponseMetadata",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
-        "RetryAttempts": int,
-    },
-)
-
-VoteSummaryTypeDef = TypedDict(
-    "VoteSummaryTypeDef",
-    {"Vote": Literal["YES", "NO"], "MemberName": str, "MemberId": str},
-    total=False,
-)
-
-VotingPolicyTypeDef = TypedDict(
-    "VotingPolicyTypeDef",
-    {"ApprovalThresholdPolicy": "ApprovalThresholdPolicyTypeDef"},
-    total=False,
-)
-
-CreateMemberOutputTypeDef = TypedDict(
-    "CreateMemberOutputTypeDef",
-    {"MemberId": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-CreateNetworkOutputTypeDef = TypedDict(
-    "CreateNetworkOutputTypeDef",
-    {"NetworkId": str, "MemberId": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-CreateNodeOutputTypeDef = TypedDict(
-    "CreateNodeOutputTypeDef", {"NodeId": str, "ResponseMetadata": "ResponseMetadata"}, total=False
-)
-
-CreateProposalOutputTypeDef = TypedDict(
-    "CreateProposalOutputTypeDef",
-    {"ProposalId": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-GetMemberOutputTypeDef = TypedDict(
-    "GetMemberOutputTypeDef",
-    {"Member": "MemberTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-GetNetworkOutputTypeDef = TypedDict(
-    "GetNetworkOutputTypeDef",
-    {"Network": "NetworkTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-GetNodeOutputTypeDef = TypedDict(
-    "GetNodeOutputTypeDef",
-    {"Node": "NodeTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
-)
-
-GetProposalOutputTypeDef = TypedDict(
-    "GetProposalOutputTypeDef",
-    {"Proposal": "ProposalTypeDef", "ResponseMetadata": "ResponseMetadata"},
-    total=False,
 )
 
 ListInvitationsOutputTypeDef = TypedDict(
@@ -421,9 +188,8 @@ ListInvitationsOutputTypeDef = TypedDict(
     {
         "Invitations": List["InvitationTypeDef"],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadata",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListMembersOutputTypeDef = TypedDict(
@@ -431,9 +197,8 @@ ListMembersOutputTypeDef = TypedDict(
     {
         "Members": List["MemberSummaryTypeDef"],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadata",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListNetworksOutputTypeDef = TypedDict(
@@ -441,15 +206,17 @@ ListNetworksOutputTypeDef = TypedDict(
     {
         "Networks": List["NetworkSummaryTypeDef"],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadata",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListNodesOutputTypeDef = TypedDict(
     "ListNodesOutputTypeDef",
-    {"Nodes": List["NodeSummaryTypeDef"], "NextToken": str, "ResponseMetadata": "ResponseMetadata"},
-    total=False,
+    {
+        "Nodes": List["NodeSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
 )
 
 ListProposalVotesOutputTypeDef = TypedDict(
@@ -457,9 +224,8 @@ ListProposalVotesOutputTypeDef = TypedDict(
     {
         "ProposalVotes": List["VoteSummaryTypeDef"],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadata",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ListProposalsOutputTypeDef = TypedDict(
@@ -467,18 +233,40 @@ ListProposalsOutputTypeDef = TypedDict(
     {
         "Proposals": List["ProposalSummaryTypeDef"],
         "NextToken": str,
-        "ResponseMetadata": "ResponseMetadata",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
     },
     total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
+LogConfigurationTypeDef = TypedDict(
+    "LogConfigurationTypeDef",
+    {
+        "Enabled": bool,
+    },
+    total=False,
+)
+
+LogConfigurationsTypeDef = TypedDict(
+    "LogConfigurationsTypeDef",
+    {
+        "Cloudwatch": "LogConfigurationTypeDef",
+    },
+    total=False,
 )
 
 _RequiredMemberConfigurationTypeDef = TypedDict(
     "_RequiredMemberConfigurationTypeDef",
-    {"Name": str, "FrameworkConfiguration": "MemberFrameworkConfigurationTypeDef"},
+    {
+        "Name": str,
+        "FrameworkConfiguration": "MemberFrameworkConfigurationTypeDef",
+    },
 )
 _OptionalMemberConfigurationTypeDef = TypedDict(
     "_OptionalMemberConfigurationTypeDef",
@@ -497,21 +285,173 @@ class MemberConfigurationTypeDef(
     pass
 
 
+MemberFabricAttributesTypeDef = TypedDict(
+    "MemberFabricAttributesTypeDef",
+    {
+        "AdminUsername": str,
+        "CaEndpoint": str,
+    },
+    total=False,
+)
+
+MemberFabricConfigurationTypeDef = TypedDict(
+    "MemberFabricConfigurationTypeDef",
+    {
+        "AdminUsername": str,
+        "AdminPassword": str,
+    },
+)
+
+MemberFabricLogPublishingConfigurationTypeDef = TypedDict(
+    "MemberFabricLogPublishingConfigurationTypeDef",
+    {
+        "CaLogs": "LogConfigurationsTypeDef",
+    },
+    total=False,
+)
+
+MemberFrameworkAttributesTypeDef = TypedDict(
+    "MemberFrameworkAttributesTypeDef",
+    {
+        "Fabric": "MemberFabricAttributesTypeDef",
+    },
+    total=False,
+)
+
+MemberFrameworkConfigurationTypeDef = TypedDict(
+    "MemberFrameworkConfigurationTypeDef",
+    {
+        "Fabric": "MemberFabricConfigurationTypeDef",
+    },
+    total=False,
+)
+
+MemberLogPublishingConfigurationTypeDef = TypedDict(
+    "MemberLogPublishingConfigurationTypeDef",
+    {
+        "Fabric": "MemberFabricLogPublishingConfigurationTypeDef",
+    },
+    total=False,
+)
+
+MemberSummaryTypeDef = TypedDict(
+    "MemberSummaryTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "Status": MemberStatusType,
+        "CreationDate": datetime,
+        "IsOwned": bool,
+        "Arn": str,
+    },
+    total=False,
+)
+
+MemberTypeDef = TypedDict(
+    "MemberTypeDef",
+    {
+        "NetworkId": str,
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "FrameworkAttributes": "MemberFrameworkAttributesTypeDef",
+        "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
+        "Status": MemberStatusType,
+        "CreationDate": datetime,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
+    total=False,
+)
+
+NetworkEthereumAttributesTypeDef = TypedDict(
+    "NetworkEthereumAttributesTypeDef",
+    {
+        "ChainId": str,
+    },
+    total=False,
+)
+
+NetworkFabricAttributesTypeDef = TypedDict(
+    "NetworkFabricAttributesTypeDef",
+    {
+        "OrderingServiceEndpoint": str,
+        "Edition": EditionType,
+    },
+    total=False,
+)
+
+NetworkFabricConfigurationTypeDef = TypedDict(
+    "NetworkFabricConfigurationTypeDef",
+    {
+        "Edition": EditionType,
+    },
+)
+
+NetworkFrameworkAttributesTypeDef = TypedDict(
+    "NetworkFrameworkAttributesTypeDef",
+    {
+        "Fabric": "NetworkFabricAttributesTypeDef",
+        "Ethereum": "NetworkEthereumAttributesTypeDef",
+    },
+    total=False,
+)
+
 NetworkFrameworkConfigurationTypeDef = TypedDict(
     "NetworkFrameworkConfigurationTypeDef",
-    {"Fabric": "NetworkFabricConfigurationTypeDef"},
+    {
+        "Fabric": "NetworkFabricConfigurationTypeDef",
+    },
+    total=False,
+)
+
+NetworkSummaryTypeDef = TypedDict(
+    "NetworkSummaryTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "Framework": FrameworkType,
+        "FrameworkVersion": str,
+        "Status": NetworkStatusType,
+        "CreationDate": datetime,
+        "Arn": str,
+    },
+    total=False,
+)
+
+NetworkTypeDef = TypedDict(
+    "NetworkTypeDef",
+    {
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "Framework": FrameworkType,
+        "FrameworkVersion": str,
+        "FrameworkAttributes": "NetworkFrameworkAttributesTypeDef",
+        "VpcEndpointServiceName": str,
+        "VotingPolicy": "VotingPolicyTypeDef",
+        "Status": NetworkStatusType,
+        "CreationDate": datetime,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
     total=False,
 )
 
 _RequiredNodeConfigurationTypeDef = TypedDict(
-    "_RequiredNodeConfigurationTypeDef", {"InstanceType": str}
+    "_RequiredNodeConfigurationTypeDef",
+    {
+        "InstanceType": str,
+    },
 )
 _OptionalNodeConfigurationTypeDef = TypedDict(
     "_OptionalNodeConfigurationTypeDef",
     {
         "AvailabilityZone": str,
         "LogPublishingConfiguration": "NodeLogPublishingConfigurationTypeDef",
-        "StateDB": Literal["LevelDB", "CouchDB"],
+        "StateDB": StateDBTypeType,
     },
     total=False,
 )
@@ -521,3 +461,161 @@ class NodeConfigurationTypeDef(
     _RequiredNodeConfigurationTypeDef, _OptionalNodeConfigurationTypeDef
 ):
     pass
+
+
+NodeEthereumAttributesTypeDef = TypedDict(
+    "NodeEthereumAttributesTypeDef",
+    {
+        "HttpEndpoint": str,
+        "WebSocketEndpoint": str,
+    },
+    total=False,
+)
+
+NodeFabricAttributesTypeDef = TypedDict(
+    "NodeFabricAttributesTypeDef",
+    {
+        "PeerEndpoint": str,
+        "PeerEventEndpoint": str,
+    },
+    total=False,
+)
+
+NodeFabricLogPublishingConfigurationTypeDef = TypedDict(
+    "NodeFabricLogPublishingConfigurationTypeDef",
+    {
+        "ChaincodeLogs": "LogConfigurationsTypeDef",
+        "PeerLogs": "LogConfigurationsTypeDef",
+    },
+    total=False,
+)
+
+NodeFrameworkAttributesTypeDef = TypedDict(
+    "NodeFrameworkAttributesTypeDef",
+    {
+        "Fabric": "NodeFabricAttributesTypeDef",
+        "Ethereum": "NodeEthereumAttributesTypeDef",
+    },
+    total=False,
+)
+
+NodeLogPublishingConfigurationTypeDef = TypedDict(
+    "NodeLogPublishingConfigurationTypeDef",
+    {
+        "Fabric": "NodeFabricLogPublishingConfigurationTypeDef",
+    },
+    total=False,
+)
+
+NodeSummaryTypeDef = TypedDict(
+    "NodeSummaryTypeDef",
+    {
+        "Id": str,
+        "Status": NodeStatusType,
+        "CreationDate": datetime,
+        "AvailabilityZone": str,
+        "InstanceType": str,
+        "Arn": str,
+    },
+    total=False,
+)
+
+NodeTypeDef = TypedDict(
+    "NodeTypeDef",
+    {
+        "NetworkId": str,
+        "MemberId": str,
+        "Id": str,
+        "InstanceType": str,
+        "AvailabilityZone": str,
+        "FrameworkAttributes": "NodeFrameworkAttributesTypeDef",
+        "LogPublishingConfiguration": "NodeLogPublishingConfigurationTypeDef",
+        "StateDB": StateDBTypeType,
+        "Status": NodeStatusType,
+        "CreationDate": datetime,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
+    total=False,
+)
+
+ProposalActionsTypeDef = TypedDict(
+    "ProposalActionsTypeDef",
+    {
+        "Invitations": List["InviteActionTypeDef"],
+        "Removals": List["RemoveActionTypeDef"],
+    },
+    total=False,
+)
+
+ProposalSummaryTypeDef = TypedDict(
+    "ProposalSummaryTypeDef",
+    {
+        "ProposalId": str,
+        "Description": str,
+        "ProposedByMemberId": str,
+        "ProposedByMemberName": str,
+        "Status": ProposalStatusType,
+        "CreationDate": datetime,
+        "ExpirationDate": datetime,
+        "Arn": str,
+    },
+    total=False,
+)
+
+ProposalTypeDef = TypedDict(
+    "ProposalTypeDef",
+    {
+        "ProposalId": str,
+        "NetworkId": str,
+        "Description": str,
+        "Actions": "ProposalActionsTypeDef",
+        "ProposedByMemberId": str,
+        "ProposedByMemberName": str,
+        "Status": ProposalStatusType,
+        "CreationDate": datetime,
+        "ExpirationDate": datetime,
+        "YesVoteCount": int,
+        "NoVoteCount": int,
+        "OutstandingVoteCount": int,
+        "Tags": Dict[str, str],
+        "Arn": str,
+    },
+    total=False,
+)
+
+RemoveActionTypeDef = TypedDict(
+    "RemoveActionTypeDef",
+    {
+        "MemberId": str,
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+VoteSummaryTypeDef = TypedDict(
+    "VoteSummaryTypeDef",
+    {
+        "Vote": VoteValueType,
+        "MemberName": str,
+        "MemberId": str,
+    },
+    total=False,
+)
+
+VotingPolicyTypeDef = TypedDict(
+    "VotingPolicyTypeDef",
+    {
+        "ApprovalThresholdPolicy": "ApprovalThresholdPolicyTypeDef",
+    },
+    total=False,
+)
